==> jc-1.4.0.tar.gz: javax/swing/TransferHandler__24TransferAction.h <==
// class javax.swing.TransferHandler$TransferAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 18eac3d2d92972ff javax_swing_TransferHandler__24TransferAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_TransferHandler__24TransferAction_H_
#define _JC_javax_swing_TransferHandler__24TransferAction_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$sub_refs	_jc_javax_swing_TransferHandler__24TransferAction$sub_refs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs	_jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$refs	_jc_javax_swing_TransferHandler__24TransferAction$refs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$nonrefs	_jc_javax_swing_TransferHandler__24TransferAction$nonrefs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$object	_jc_javax_swing_TransferHandler__24TransferAction$object;

typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vmethods	_jc_javax_swing_TransferHandler__24TransferAction$vmethods;
typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vtable	_jc_javax_swing_TransferHandler__24TransferAction$vtable;
typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vtype	_jc_javax_swing_TransferHandler__24TransferAction$vtype;

// Constructors
extern void _jc_javax_swing_TransferHandler__24TransferAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_TransferHandler__24TransferAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_TransferHandler__24TransferAction$method_info$actionPerformed$9046a9754e643ffd;

// Static methods
extern struct _jc_java_awt_datatransfer_Clipboard$object *_jc_javax_swing_TransferHandler__24TransferAction$method$getClipboard$a5787cd2badfb223(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_TransferHandler__24TransferAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_TransferHandler__24TransferAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_TransferHandler__24TransferAction$vmethods	javax_swing_TransferHandler__24TransferAction;
};

// Vtype
struct _jc_javax_swing_TransferHandler__24TransferAction$vtype {
	_jc_type			type;
	_jc_javax_swing_TransferHandler__24TransferAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_TransferHandler__24TransferAction$sub_refs {
	struct _jc_java_lang_String$object	*command;
};

// Reference instance fields (object)
struct _jc_javax_swing_TransferHandler__24TransferAction$refs {
    _jc_javax_swing_TransferHandler__24TransferAction$sub_refs	javax_swing_TransferHandler__24TransferAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_TransferHandler__24TransferAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs	javax_swing_TransferHandler__24TransferAction;
};

// Object instance structure
struct _jc_javax_swing_TransferHandler__24TransferAction$object {
	_jc_javax_swing_TransferHandler__24TransferAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_TransferHandler__24TransferAction$vtype	*vtype;
	_jc_javax_swing_TransferHandler__24TransferAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_TransferHandler__24TransferAction$vtype _jc_javax_swing_TransferHandler__24TransferAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_TransferHandler__24TransferAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_TransferHandler__24TransferAction$class_object;

#endif	/* _JC_javax_swing_TransferHandler__24TransferAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/TransferHandler__24TransferAction.h <==
// class javax.swing.TransferHandler$TransferAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class ab144617f70f842 javax_swing_TransferHandler__24TransferAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_TransferHandler__24TransferAction_H_
#define _JC_javax_swing_TransferHandler__24TransferAction_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$sub_refs	_jc_javax_swing_TransferHandler__24TransferAction$sub_refs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs	_jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$refs	_jc_javax_swing_TransferHandler__24TransferAction$refs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$nonrefs	_jc_javax_swing_TransferHandler__24TransferAction$nonrefs;
typedef struct _jc_javax_swing_TransferHandler__24TransferAction$object	_jc_javax_swing_TransferHandler__24TransferAction$object;

typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vmethods	_jc_javax_swing_TransferHandler__24TransferAction$vmethods;
typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vtable	_jc_javax_swing_TransferHandler__24TransferAction$vtable;
typedef const struct _jc_javax_swing_TransferHandler__24TransferAction$vtype	_jc_javax_swing_TransferHandler__24TransferAction$vtype;

// Constructors
extern void _jc_javax_swing_TransferHandler__24TransferAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_TransferHandler__24TransferAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_TransferHandler__24TransferAction$method_info$actionPerformed$9046a9754e643ffd;

// Static methods
extern struct _jc_java_awt_datatransfer_Clipboard$object *_jc_javax_swing_TransferHandler__24TransferAction$method$getClipboard$a5787cd2badfb223(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_TransferHandler__24TransferAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_TransferHandler__24TransferAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_TransferHandler__24TransferAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_TransferHandler__24TransferAction$vmethods	javax_swing_TransferHandler__24TransferAction;
};

// Vtype
struct _jc_javax_swing_TransferHandler__24TransferAction$vtype {
	_jc_type			type;
	_jc_javax_swing_TransferHandler__24TransferAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_TransferHandler__24TransferAction$sub_refs {
	struct _jc_java_lang_String$object	*command;
};

// Reference instance fields (object)
struct _jc_javax_swing_TransferHandler__24TransferAction$refs {
    _jc_javax_swing_TransferHandler__24TransferAction$sub_refs	javax_swing_TransferHandler__24TransferAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_TransferHandler__24TransferAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_TransferHandler__24TransferAction$sub_nonrefs	javax_swing_TransferHandler__24TransferAction;
};

// Object instance structure
struct _jc_javax_swing_TransferHandler__24TransferAction$object {
	_jc_javax_swing_TransferHandler__24TransferAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_TransferHandler__24TransferAction$vtype	*vtype;
	_jc_javax_swing_TransferHandler__24TransferAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_TransferHandler__24TransferAction$vtype _jc_javax_swing_TransferHandler__24TransferAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_TransferHandler__24TransferAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_TransferHandler__24TransferAction$class_object;

#endif	/* _JC_javax_swing_TransferHandler__24TransferAction_H_ */
